summaryrefslogtreecommitdiffstats
path: root/controller-api
diff options
context:
space:
mode:
Diffstat (limited to 'controller-api')
-rw-r--r--controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/zone/ZoneRegistry.java7
1 files changed, 2 insertions, 5 deletions
diff --git a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/zone/ZoneRegistry.java b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/zone/ZoneRegistry.java
index d808b4b7adb..72f9f5b7ce2 100644
--- a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/zone/ZoneRegistry.java
+++ b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/zone/ZoneRegistry.java
@@ -39,8 +39,8 @@ public interface ZoneRegistry {
/** Returns the API endpoints of all known config servers in the given zone */
List<URI> getConfigServerUris(ZoneId zoneId);
- /** Returns the URI for the config server VIP in the given zone */
- URI getConfigServerVipUri(ZoneId zoneId);
+ /** Returns the URI for the config server VIP in the given zone, or Optional.empty() if no VIP exists */
+ default Optional<URI> getConfigServerVipUri(ZoneId zoneId) { return Optional.empty(); }
/** Returns all possible API endpoints of all known config servers and config server VIPs in the given zone */
List<URI> getConfigServerApiUris(ZoneId zoneId);
@@ -87,7 +87,4 @@ public interface ZoneRegistry {
/** Returns a URL used to generate flashy badges from strings. */
URI badgeUrl();
- /** Returns a URL to the controller's api endpoint */
- URI apiUrl();
-
}